==> moyoung_ble_plugin-1.0.3.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/TrainHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHistoryTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingInfo;
import com.crrepa.ble.conn.listener.CRPTrainingChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.TrainBean;

import java.util.List;

import io.flutter.plugin.common.MethodCall;

public class TrainHandler extends BaseConnectionEventChannelHandler {
    TrainBean trainBean = new TrainBean();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setTrainingListener(new CRPTrainingChangeListener() {
            @Override
            public void onHistoryTrainingChange(List<CRPHistoryTrainingInfo> historyTrainList) {
                if (eventSink == null) {
                    return;
                }
                trainBean.setType(trainBean.HISTORY_TRAINING_CHANGE);
                trainBean.setHistoryTrainList(historyTrainList);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTrainingChange(CRPTrainingInfo info) {
                if (eventSink == null) {
                    return;
                }
                trainBean.setType(trainBean.TRAINING_CHANGE);
                trainBean.setTrainingInfo(info);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }
        });
    }
}

==> moyoung_ble_plugin-1.0.11.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/TrainHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHistoryTrainingInfo;
import com.crrepa.ble.conn.bean.CRPTrainingInfo;
import com.crrepa.ble.conn.listener.CRPTrainingChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.TrainBean;

import java.util.List;

import io.flutter.plugin.common.MethodCall;

public class TrainHandler extends BaseConnectionEventChannelHandler {
    TrainBean trainBean = new TrainBean();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        Log.d("setConnListener: ", "进入了新版锻炼监听");
        connection.setTrainingListener(new CRPTrainingChangeListener() {
            @Override
            public void onHistoryTrainingChange(List<CRPHistoryTrainingInfo> historyTrainList) {
                Log.d("onHistoryTrainingChange","获取新版锻炼的历史记录");
                if (eventSink == null) {
                    return;
                }
                trainBean.setType(TrainBean.HISTORY_TRAINING_CHANGE);
                trainBean.setHistoryTrainList(historyTrainList);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTrainingChange(CRPTrainingInfo info) {
                Log.d("onTrainingChange","新版锻炼变化");
                if (eventSink == null) {
                    return;
                }
                trainBean.setType(TrainBean.TRAINING_CHANGE);
                trainBean.setTrainingInfo(info);
                String jsonStr = GsonUtils.get().toJson(trainBean, TrainBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }
        });
    }
}
